package afficheur;
import java.util.*;
import java.io.FileWriter;
import java.io.IOException;

public class AfficheurHTML implements Afficheur {

    
    // Ce champ contient le nom du fichier HTML dans lequel on souhaite 
    // ecrire
    public String fileName;

    //Ce champ contient le pointeur vers le fichier html manipule
    private FileWriter file;

    //Cette méthode permet de traduire une chaîne de caractere
    // en html en remplaçant les caracteres speciaux html par leur
    //code correspondant en html
    public static final String escapeHTML(String s){
	StringBuffer sb = new StringBuffer();
	int n = s.length();
	for (int i = 0; i < n; i++) {
	    char c = s.charAt(i);
	    switch (c) {
	    case '<': sb.append("&lt;"); break;
	    case '>': sb.append("&gt;"); break;
	    case '&': sb.append("&amp;"); break;
	    case '"': sb.append("&quot;"); break;
	    // be carefull with this one (non-breaking white space)
	    case ' ': sb.append("&nbsp;");break;         
         
	    default:  sb.append(c); break;
	    }
	}
	return sb.toString();
    }

    //Le createur ouvre le fichier et met les balises initiales
    // au debut du fichier
    public AfficheurHTML(String _fileName){
	this.fileName=_fileName;
	try{
	    this.file=new FileWriter(_fileName);
	    file.write("<html>\n<body style=\"font-family: monospace\">\n");
	}
	catch(IOException ioe){
	    System.out.println("Le fichier html n'a pas pu etre ouvert");
	    System.exit(1);
	}
    }

    //Cette fonction ecrit la chaine donnee en entree
    // dans le fichier file
    public void print(String chaine){
	try{
	    file.write(escapeHTML(chaine));
	}
	catch(IOException ioe){
	    System.out.println("Le fichier html n'a pas pu etre ouvert");
	    System.exit(1);
	}
    }

    //Cette fonction ecrit en couleur la chaine donnee en entree
    //dans le fichier file 
    public void print(String chaine, String couleur){
	try{
	    file.write("<font color="+couleur+">");
	    file.write(escapeHTML(chaine));	
	    file.write("</font>");
	}
	catch(IOException ioe){
	    System.out.println("Le fichier html n'a pas pu etre ouvert");
	    System.exit(1);
	}
    }

    //Cette fonction permet d'aller a la ligne
    public void newline(){
	try{
	    file.write("<br>\n");	
	}
	catch(IOException ioe){
	    System.out.println("Le fichier html n'a pas pu etre ouvert");
	    System.exit(1);
	}
    }


    //Cette fonction permet de mettre un espacs
    public void espace(){
	try{
	    file.write("&nbsp;");
	}
	catch(IOException ioe){
	    System.out.println("Le fichier html n'a pas pu etre ouvert");
	    System.exit(1);
	}
    }

    //Cette fonction doit etre appele pour finaliser l'ecriture
    //dans le fichier html
    //Elle met les balises de fin de fichiers et ferme le fichier
    public void termine(){
	try{
	    file.write("</body>\n</html>\n");
	    file.close();
	}
	catch(IOException ioe){
	    System.out.println("Le fichier html n'a pas pu etre ouvert");
	    System.exit(1);
	}
    }

}